@@ -6,7 +6,7 @@ pkg.env <- new.env()
 }
 
 .onAttach = function(libname, pkgname){
-  packageStartupMessage("Recent changes to NWIS data may affect dataRetrieval output. 
-Please see http://help.waterdata.usgs.gov/news/061016 
+  packageStartupMessage("USGS is switching from http to https: 
+Please see https://help.waterdata.usgs.gov/news/December%205%2C%202016
 for more information.")  
 }
